@@ -20,8 +20,7 @@ use VSGDR::UnitTest::TestSet::Representation;
 use VSGDR::UnitTest::TestSet::Resx;
 
 use Getopt::Euclid qw( :vars<opt_> );
-use List::MoreUtils qw{firstidx} ;
-use version ; our $VERSION = qv('1.2.8');
+use version ; our $VERSION = qv('1.2.6');
 use Data::Dumper;
 use File::Basename;
 use Smart::Comments;
@@ -31,23 +30,14 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
                           , xls => "XLS"
                           , xml => "XML"
                           ) ;
-my %ValidParserMakeArgs2 = ( vb  => "NET2::VB"
-                           , cs  => "NET2::CS"
-                           ) ;                          
-                          
 #my @validSuffixes       = keys %ValidParserMakeArgs ;
 my @validSuffixes       = map { '.'.$_ } keys %ValidParserMakeArgs ;
 
 
-my $version             = $opt_version ;
-
-
 my @infiles         = @opt_infile ;
 my $outFile         = $opt_outfile ;
 
 my($outfname, $outdirectories, $outsfx) = fileparse($outFile, @validSuffixes);
-croak 'Invalid output file'   unless defined $outsfx ;    
-
 $outsfx       = substr(lc $outsfx,1) ;
     
 my $outpfx          = $outfname;
@@ -70,14 +60,8 @@ my @cleanupScripts = () ;
 my @initScripts    = () ;
 
 
-my %Parsers            = () ;
-# if output is needed in ssdt unit test format  add in a .net2 parser to the list
-if ($version == 1)  {
-    $Parsers{${outsfx}}    = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
-}
-else {
-    $Parsers{"${outsfx}2"} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${outsfx}} } );
-}
+my %Parsers = () ;
+$Parsers{${outsfx}} = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${outsfx}} } );
 
 my @testSets = () ;
 my %test_testScripts  = () ;
@@ -93,31 +77,12 @@ for my $testFile (@infiles) { ### testfile ..                       done
     $insfx          = substr(lc $insfx,1) ;
 
     croak 'Invalid input file'  unless exists $ValidParserMakeArgs{$insfx} ;
-    
-    $Parsers{${insfx}}     = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } )
+    $Parsers{${insfx}}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } )
         unless exists $Parsers{${insfx}} ;
-    # if input is in a .net language, add in a .net2 parser to the list
-    if ( firstidx { $_ eq ${insfx} } ['cs','vb']  != -1 ) {
-        $Parsers{"${insfx}2"}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${insfx}} } )
-            unless exists $Parsers{"${insfx}2"} ;
-    }
 
 ### Parsing test file
 
-    my $testSet         = undef ;
-    eval {
-        $testSet         = $Parsers{$insfx}->deserialise($testFile);
-        } ;
-    if ( ! defined $testSet && exists $Parsers{"${insfx}2"}) {
-        eval {
-            $testSet     = $Parsers{"${insfx}2"}->deserialise($testFile);
-            }
-    }
-    else {
-        croak 'Parsing failed.'; 
-    }
-
-    
+    my $testSet         = $Parsers{$insfx}->deserialise($testFile);
     push @testSets, $testSet ;
     $testSet = undef ;
 
@@ -238,13 +203,7 @@ $mergedTestSet->tests(\@testA) ;
 
 ### Serialising parser
 
-if ($version == 1)  {
-    $Parsers{$outsfx}->serialise($opt_outfile,$mergedTestSet);
-}
-else {
-    $Parsers{"${outsfx}2"}->serialise($opt_outfile,$mergedTestSet);
-}
-
+$Parsers{$outsfx}->serialise($opt_outfile,$mergedTestSet);
 
 ### Cloning scripts
 
@@ -270,7 +229,7 @@ mergeGDRTests.pl - Merge multiple GDR test files into one combined file.
 
 =head1 VERSION
 
-1.2.8
+1.2.6
 
 =head1 USAGE
 
@@ -311,14 +270,6 @@ Specify the name of the required class
 =for Euclid:
     classname.type:    string
 
-=item  -v[er][sion] [=]<outputversion>
-
-Output version type
-
-=for Euclid:
-    outputversion.type:    /[12]/
-    outputversion.default:  1
-
 
 
 =back
